summaryrefslogtreecommitdiff
path: root/framework/Web/UI/TPage.php
diff options
context:
space:
mode:
authorxue <>2005-12-16 15:26:03 +0000
committerxue <>2005-12-16 15:26:03 +0000
commit47ef532b8fca6e9b8935c97aaae3253672b8455e (patch)
tree835e4e717bec50122ba383dea940b39550edcc8b /framework/Web/UI/TPage.php
parent1d1e6bc5b41c9a95c4ada79b12aeba149887d92e (diff)
Fixed name of TConfigurationException.
Diffstat (limited to 'framework/Web/UI/TPage.php')
-rw-r--r--framework/Web/UI/TPage.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/framework/Web/UI/TPage.php b/framework/Web/UI/TPage.php
index 8d2c9686..e01cb7f5 100644
--- a/framework/Web/UI/TPage.php
+++ b/framework/Web/UI/TPage.php
@@ -677,12 +677,12 @@ class TPage extends TTemplateControl
/**
* Ensures the control is rendered within a form.
* @param TControl the control to be rendered
* @throws TInvalidConfigurationException if the control is outside of the form
*/
public function ensureRenderInForm($control)
{
if(!$this->_inFormRender)
- throw new TInvalidConfigurationException('page_control_outofform',get_class($control),$control->getID(false));
+ throw new TConfigurationException('page_control_outofform',get_class($control),$control->getID(false));
}
/**
@@ -691,7 +691,7 @@ class TPage extends TTemplateControl
public function beginFormRender($writer)
{
if($this->_formRendered)
- throw new TInvalidConfigurationException('page_singleform_required');
+ throw new TConfigurationException('page_singleform_required');
$this->_formRendered=true;
$this->_inFormRender=true;
$cs=$this->getClientScript();
@@ -677,12 +677,12 @@ class TPage extends TTemplateControl
* Ensures the control is rendered within a form.
* @param TControl the control to be rendered
- * @throws TInvalidConfigurationException if the control is outside of the form
+ * @throws TConfigurationException if the control is outside of the form
*/
public function ensureRenderInForm($control)